@@ -422,18 +422,20 @@ def getDictionary(value) :
     return resultantDictionary
 
 def getSettingInjectionListFromSettingValue(settingValue) :
-    if StringHelper.isNotBlank(settingValue) :
+    if ObjectHelper.isNotNone(settingValue) and StringHelper.isNotBlank(settingValue) :
         splitedSettingValue = settingValue.split(OPEN_SETTING_INJECTION)
         settingValueList = []
         completeSettingValue = c.NOTHING
         for segment in splitedSettingValue if settingValue.startswith(OPEN_SETTING_INJECTION) else splitedSettingValue[1:] :
-            if not segment is None and not segment.count(c.OPEN_DICTIONARY) is None and not segment.count(c.OPEN_DICTIONARY) == segment.count(c.CLOSE_DICTIONARY) and 0 < segment.count(c.OPEN_DICTIONARY) :
-                completeSettingValue += segment
-            else :
-                splitedSegment = segment.split(CLOSE_SETTING_INJECTION)
-                completeSettingValue += splitedSegment[0]
-                settingValueList.append(f'{OPEN_SETTING_INJECTION}{completeSettingValue}{CLOSE_SETTING_INJECTION}')
-                completeSettingValue = c.NOTHING
+            if ObjectHelper.isNotNone(segment) and StringHelper.isNotBlank(segment) :
+                if not segment.count(c.OPEN_DICTIONARY) is None and not segment.count(c.OPEN_DICTIONARY) == segment.count(c.CLOSE_DICTIONARY) and 0 < segment.count(c.OPEN_DICTIONARY) :
+                    completeSettingValue += segment
+                else :
+                    splitedSegment = segment.split(CLOSE_SETTING_INJECTION)
+                    completeSettingValue += splitedSegment[0]
+                    if ObjectHelper.isNotNone(completeSettingValue) and StringHelper.isNotBlank(completeSettingValue) :
+                        settingValueList.append(f'{OPEN_SETTING_INJECTION}{completeSettingValue}{CLOSE_SETTING_INJECTION}')
+                    completeSettingValue = c.NOTHING
         return settingValueList
     return []
 
@@ -458,12 +460,15 @@ def isSettingInjection(settingValue) :
         isinstance(settingValue, str) and
         settingValue.startswith(OPEN_SETTING_INJECTION) and
         settingValue.endswith(CLOSE_SETTING_INJECTION) and
-        containsSettingInjection(settingValue)
+        containsOnlyOneSettingInjection(settingValue)
     )
 
 def containsSettingInjection(settingValue) :
     return False if not containsValidSettingInjection(settingValue) else 0 < len(getSettingInjectionListFromSettingValue(settingValue))
 
+def containsOnlyOneSettingInjection(settingValue) :
+    return False if not containsValidSettingInjection(settingValue) else 2 >= len(getSettingInjectionListFromSettingValue(settingValue))
+
 def getSettingInjectionValue(settingKey, settingValue, nodeKey, settingTree) :
     unwrapedSettingInjectionValue = getUnwrappedSettingInjection(settingValue)
     if isSettingKey(unwrapedSettingInjectionValue) :
